summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_coreboot.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2015-08-15 15:18:58 +0200
committerHolger Levsen <holger@layer-acht.org>2015-08-15 15:18:58 +0200
commit571b063077bc37e7b85478cbfc9fa3a4c41821db (patch)
treea030c44894937ca47747f146190e1f80214a479b /bin/reproducible_coreboot.sh
parentce26a6eec7667c47005f3ee37f54e95de0e52b22 (diff)
downloadjenkins.debian.net-571b063077bc37e7b85478cbfc9fa3a4c41821db.tar.xz
reproducible: s#debbindiff#diffoscope#g in most of the output
Diffstat (limited to 'bin/reproducible_coreboot.sh')
-rwxr-xr-xbin/reproducible_coreboot.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_coreboot.sh b/bin/reproducible_coreboot.sh
index cb368803..fb7e011b 100755
--- a/bin/reproducible_coreboot.sh
+++ b/bin/reproducible_coreboot.sh
@@ -148,7 +148,7 @@ save_coreboot_results b2
# clean up builddir to save space on tmpfs
rm -r $TMPBUILDDIR/coreboot
# run debbindiff on the results
TIMEOUT="30m"
DBDSUITE="unstable"
DBDVERSION="$(schroot --directory /tmp -c source:jenkins-reproducible-${DBDSUITE}-debbindiff debbindiff -- --version 2>&1)"
@@ -166,7 +166,7 @@ cd $TMPDIR/b1
for i in $(ls -1d *| sort -u) ; do
let ALL_ROMS+=1
if [ -f $i/coreboot.rom ] ; then
- call_debbindiff $i coreboot.rom
+ call_diffoscope $i coreboot.rom
get_filesize $i/coreboot.rom
if [ -f $TMPDIR/$i.html ] ; then
mv $TMPDIR/$i.html $BASE/coreboot/dbd/$i.html
@@ -148,7 +148,7 @@ save_coreboot_results b2
# clean up builddir to save space on tmpfs
rm -r $TMPBUILDDIR/coreboot
-# run debbindiff on the results
+# run diffoscope on the results
TIMEOUT="30m"
DBDSUITE="unstable"